ozi-fix webui

### {_('adm-disclaimer-title')}

×

{disclaimer_text}

### {_('btn-options')}

×

{_('term-user-interface')} {_('opt-menu-language-text')}
{_('term-output')} {_('opt-menu-copyright-head-input')}

#####

{config['new']['copyright_head'] if config['new']['copyright_head'] else COPYRIGHT_HEAD}
{_('opt-menu-update-wrapfile').replace('$value', '')}
{_('term-input')}
{_('opt-menu-strict').replace('$value', '')}
{_('opt-menu-pretty').replace('$value', '')}

# {_('btn-edit')}